@@ -1,11 +1,8 @@
 """Tests for certbot_dns_gehirn._internal.dns_gehirn."""
 
 import unittest
+from unittest import mock
 
-try:
-    import mock
-except ImportError: # pragma: no cover
-    from unittest import mock # type: ignore
 from requests.exceptions import HTTPError
 
 from certbot.compat import os
